MultiArmorResult

Struct MultiArmorResult 

pub struct MultiArmorResult {
    pub bytes: Arc<[u8]>,
    pub blocks: Vec<ArmorBlock>,
    pub cleartext: Option<Arc<str>>,
}
The result of decoding input that may contain several armor blocks and/or a cleartext signed message.

Fields

bytes: Arc<[u8]>

All blocks’ decoded binary data, concatenated in input order, so that packet byte spans share a single address space.

blocks: Vec<ArmorBlock>

The decoded blocks, in input order, with their byte ranges.

cleartext: Option<Arc<str>>

The dash-unescaped cleartext, if the input contained a -----BEGIN PGP SIGNED MESSAGE----- section.