PacketBody

Enum PacketBody 

pub enum PacketBody {
Show 19 variants Pkesk(PkeskPacket), Signature(SignaturePacket), Skesk(SkeskPacket), OnePassSignature(OnePassSignaturePacket), SecretKey(SecretKeyPacket), PublicKey(PublicKeyPacket), SecretSubkey(SecretKeyPacket), CompressedData(CompressedDataPacket), SymmetricallyEncryptedData(SymmetricallyEncryptedDataPacket), Marker(MarkerPacket), LiteralData(LiteralDataPacket), UserId(UserIdPacket), PublicSubkey(PublicKeyPacket), UserAttribute(UserAttributePacket), Seipd(SeipdPacket), Mdc(MdcPacket), AeadEncryptedData(AeadEncryptedDataPacket), Padding(PaddingPacket), Unknown(Vec<u8>),
}
The typed body of a parsed packet.

Each variant contains the parsed structure for that packet type. Unknown or unsupported packet types are stored as raw bytes.

Variants



Pkesk(PkeskPacket)

Public-Key Encrypted Session Key packet (tag 1).



Signature(SignaturePacket)

Signature packet (tag 2).



Skesk(SkeskPacket)

Symmetric-Key Encrypted Session Key packet (tag 3).



OnePassSignature(OnePassSignaturePacket)

One-Pass Signature packet (tag 4).



SecretKey(SecretKeyPacket)

Secret key packet (tag 5).



PublicKey(PublicKeyPacket)

Public key packet (tag 6).



SecretSubkey(SecretKeyPacket)

Secret subkey packet (tag 7).



CompressedData(CompressedDataPacket)

Compressed Data packet (tag 8).



SymmetricallyEncryptedData(SymmetricallyEncryptedDataPacket)

Symmetrically Encrypted Data packet (tag 9, legacy).



Marker(MarkerPacket)

Marker packet (tag 10, obsolete).



LiteralData(LiteralDataPacket)

Literal Data packet (tag 11).



UserId(UserIdPacket)

User ID packet (tag 13).



PublicSubkey(PublicKeyPacket)

Public subkey packet (tag 14).



UserAttribute(UserAttributePacket)

User Attribute packet (tag 17).



Seipd(SeipdPacket)

Symmetrically Encrypted Integrity Protected Data packet (tag 18).



Mdc(MdcPacket)

Modification Detection Code packet (tag 19).



AeadEncryptedData(AeadEncryptedDataPacket)

AEAD Encrypted Data packet (tag 20, RFC 9580).



Padding(PaddingPacket)

Padding packet (tag 21, RFC 9580).



Unknown(Vec<u8>)

Unknown or unsupported packet type.