Function parse_bytes
Source pub fn parse_bytes(bytes: impl Into<Arc<[u8]>>) -> Result<Vec<Packet>>
Parses raw binary PGP data into a vector of packets.
Use this when you have already decoded the armor or are working
with raw binary PGP data.
Arguments
bytes - Raw binary PGP packet data
Errors
Returns an error if the packet structure is malformed.