pub struct MarkerPacket {
pub valid: bool,
}Expand description
Parsed Marker packet.
The Marker packet is obsolete and contains only the three bytes “PGP”. It was used to indicate newer message formats to older PGP versions.
Fields
valid: boolWhether the packet contains valid “PGP” magic bytes.